@@ -21,6 +21,7 @@ import logging
 import platform
 import random
 import signal
+import sys
 from asyncio import AbstractEventLoop, CancelledError
 from typing import List, Optional, Tuple, cast
 
@@ -95,7 +96,7 @@ def _handle_game_completed(_player_id: str, message: Message) -> None:
 
 
 def _handle_game_state_change(_player_id: str, message: Message) -> None:
-    "Handle the game state change event"
+    """Handle the game state change event"""
     context = cast(GameStateChangeContext, message.context)
     if context.recent_history:
         history = context.recent_history[-1]
@@ -183,7 +184,7 @@ def _add_signal_handlers(loop: AbstractEventLoop) -> None:
     """Add signal handlers so shutdown can be handled normally."""
     log.info("Adding signal handlers...")
     for sig in SHUTDOWN_SIGNALS:
-        if platform.system() == "win32":
+        if platform.system() == "Windows" or sys.platform == "win32":  # stupid MyPy
             signal.signal(sig, lambda s, f: asyncio.create_task(_terminate()))  # type: ignore
         else:
             loop.add_signal_handler(sig, lambda: asyncio.create_task(_terminate()))
